package cn.iocoder.yudao.module.delivery.controller.admin;


import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.dict.core.dto.DictDataRespDTO;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.delivery.entity.CustomerAnalysisReq;

import cn.iocoder.yudao.module.delivery.entity.SalesAnalysisExcelResp;
import cn.iocoder.yudao.module.delivery.entity.SalesAnalysisReq;
import cn.iocoder.yudao.module.delivery.entity.SalesAnalysisResp;
import cn.iocoder.yudao.module.delivery.service.SalesAnalysisService;
import cn.iocoder.yudao.module.system.api.dict.DictDataApi;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

/**
 * (SalesAnalysis)销售分析报表
 *
 * @author lanbm add
 * @since 2024-03-31
 */
@RestController
@RequestMapping("/Report/SalesAnalysis")
public class SalesAnalysisControl {

    @Autowired
    private SalesAnalysisService salesAnalysisService;

    /*
    数据字典项
    */
    @Autowired
    private DictDataApi dictDataApi;

    /*
     根据原始信息计算逻辑展示信息 lanbm 2024-04-29 add
     */
    private SalesAnalysisResp calBis(SalesAnalysisResp r) {
        String sTemp = "";
        //付款方
        if (r.getDrawee().equals("1")) {
            if (r.getCfResourceType().equals("1")) {
                r.setShowResourceType("开发客户");
            } else if (r.getCfResourceType().equals("2")) {
                r.setShowResourceType("公司客户");
            }

            if (r.getCfYeJiType().equals("0")) {
                r.setShowYeJiType("老客户");

            } else if (r.getCfYeJiType().equals("1")) {
                r.setShowYeJiType("新客户");
            }
            sTemp = "发货方";
        } else if (r.getDrawee().equals("2")) {
            if (r.getShResourceType().equals("1")) {
                r.setShowResourceType("开发客户");
            } else if (r.getShResourceType().equals("2")) {
                r.setShowResourceType("公司客户");
            }

            if (r.getShYeJitype().equals("0")) {
                r.setShowYeJiType("老客户");

            } else if (r.getShYeJitype().equals("1")) {
                r.setShowYeJiType("新客户");
            }
            sTemp = "收货方";
        } else if (r.getDrawee().equals("3")) {
            if (r.getCfResourceType().equals("1")) {
                r.setShowResourceType("开发客户");
            } else if (r.getCfResourceType().equals("2")) {
                r.setShowResourceType("公司客户");
            }

            if (r.getCfYeJiType().equals("0")) {
                r.setShowYeJiType("老客户");

            } else if (r.getCfYeJiType().equals("1")) {
                r.setShowYeJiType("新客户");
            }
            sTemp = "自定义";
        }
        r.setDraweeName(sTemp);
        return r;
    }

    /*
    客户分析列表 lanbm 2024-04-02 add
    */
    @GetMapping("/getListPage")
    public CommonResult<PageResult<SalesAnalysisResp>>
    getListPage(@Valid SalesAnalysisReq query) {
        System.out.println("订单分析查询条件：" + query);
        /*
        SalesAnalysisReq query = JSON.parseObject(JSON.toJSONString(map),
                SalesAnalysisReq.class);

         */

        //订单状态
        List<DictDataRespDTO> dic_order_status =
                dictDataApi.getDictDatas("order_status");
        Map<String, String> map_order_status = new HashMap<>();
        for (DictDataRespDTO d : dic_order_status
        ) {
            map_order_status.put(d.getValue(), d.getLabel());
        }

        PageResult<SalesAnalysisResp> pageResult =
                salesAnalysisService.getListPage(query);

        int nPm = query.getStart() + 1;
        String sTemp = "";
        for (SalesAnalysisResp r : pageResult.getList()
        ) {
            r.setPx(nPm);
            nPm++;

            //订单状态
            r.setStatusName(map_order_status.get(r.getStatus()));

            String sType = "";
            if (r.getOrdertype() == 2) {
                //是重货，非泡货
                sType = "是/否";
            } else if (r.getOrdertype() == 3) {
                sType = "否/是";

            } else if (r.getOrdertype() == 1) {
                sType = "普货";
            }
            r.setOrdertypeShow(sType);

            //业务数据逻辑运算
            r = calBis(r);

            if (r.getUseweightunit() == null) r.setUseweightunit("无");
            if (r.getUsevolumeunit() == null) r.setUsevolumeunit("无");
            r.setZpUnitShow(r.getUseweightunit() + "/" + r.getUsevolumeunit());


        }
        return success(pageResult);
    }

    /*
     lanbm 2024-04-24 add
     */
    @GetMapping("/exportExcel")
    @ApiOperation("导出销售分析数据")
    @OperateLog(type = EXPORT)
    public void export(HttpServletResponse response,
                       @Valid SalesAnalysisReq Req)
            throws IOException {

        System.out.println("订单分析查询数据导出查询条件：" + Req);
        List<SalesAnalysisExcelResp> list = salesAnalysisService.getList(Req);
        ExcelUtils.write(response, "销售分析数据.xls", "销售分析数据",
                SalesAnalysisExcelResp.class, list);
    }
}
